function [foil] = fitTheodorsen(foil,vessel,U,plot_flag)

% Checking for plot variables
if ~exist('plot_flag','var')
    plot_flag = '0';
end

% Retreiving variables
g    = foil.main.g;
cord = foil.main.cord;

% Defining vessel frequency range
freqs  = vessel.freqs;
nfreqs = length(freqs);

% Defining a random frequency range for plot purposes
freqs_tmp  = 0.01:0.01:10;            
nfreqs_tmp = length(freqs_tmp);

% Preallocating memory 
[Ckf,Skf,kf]             = deal(zeros(nfreqs,1));
[Ckf_tmp,Skf_tmp,kf_tmp] = deal(zeros(nfreqs_tmp,1));

% Looping vessel frequencies
for i = 1:nfreqs; 
    
    w   = freqs(i);
    w_e = w + w^2/g*U;

    [Ckf(i),kf(i),Skf(i)] = theodorsen(cord,U,w_e); 

end

% Looping total frequency range
for j = 1:nfreqs_tmp;

    w   = freqs_tmp(j);
    w_e = w + w^2/g*U;

    [Ckf_tmp(j),kf_tmp(j),Skf_tmp(j)] = theodorsen(cord,U,w_e);          

end

% FITTING:
% Fitting numerical transfer-functions to the Theodorsen and Sears function
% Initial condition: Transfer-function is not stable
stableCkf = 0;

while stableCkf == 0;
        
        % Initial order of transfer-function
        order = 4;
        ord_num = order;    % Numerator ord.
        ord_den = order;    % Denominator ord.
        [numCkf,denCkf,frespCkf,stableCkf] = fitting(Ckf_tmp,kf_tmp,ord_num,ord_den,[]);
        
        % User defined order of tf, if output from fitting is unstable
        if stableCkf == 0;
            disp('Approximation for Theodorsen function is not stable - reduce order:');
            str   = sprintf('Current order: %f',order); disp(str);
            order = input('Input new order or press enter to ignore: ');
            
            if isempty(order)
                stableCkf = 1;
            end     
        end
end

% Making the tf only dependent on frequency, w_e as kf (reduced frequency)
% is implemented in the transferfunction 
tmp_num    = redfreq(ord_num,cord,U);
tmp_den    = redfreq(ord_den,cord,U);
numCwe = numCkf*tmp_num;
denCwe = denCkf*tmp_den;

% Saving to structure 
foil.theodorsen.num = numCwe;
foil.theodorsen.den = denCwe;

%stableSkf = 0;

% while stableSkf == 0;
% 
%         order = 1;
%         ord_num = order;
%         ord_den = order;
%         [numSkf,denSkf,frespSkf,stableSkf] = fitting(Skf_tmp,kf_tmp,ord_num,ord_den,[]);
%         
%         if stableSkf == 0;
%             disp('Approximation for Sears function is not stable - reduce order:');
%             str   = sprintf('Current order: %f',order); disp(str);
%             order = input('Input new order or press enter to ignore: ');
%             
%             if isempty(order)
%                 stableSkf = 1;
%             end     
%         end
% end
% 
% tmp    = redfreq(order,cord,U);
% numSwe = numSkf*tmp;
% denSwe = denSkf*tmp;
%     
% foil.sears.num{i,j} = numSwe;
% foil.sears.den{i,j} = denSwe;

%% Plotting

if strcmp(plot_flag,'1'); 
    
    figno  = floor(100+U);
    
    w_stop = 2;                             % Stop-frequency for plotting
    [~, i] = min(abs(freqs_tmp-w_stop));    % Finding stop-freq. index 

    S1 = 180/pi;   % rad->deg

    figure(figno)
    % Plotting actual Theodorsen response and phase shift
    subplot(2,1,1); 
    hold on
    grid on
    plot(kf_tmp(1:i),abs(Ckf_tmp(1:i)),'-b','LineWidth',2) 
    plot(kf,abs(Ckf),'or','MarkerSize',8)
    %plot(kf_tmp(1:i),abs(frespCkf(1:i)),'--g')
    legend('All frequencies','Vessel frequencies, w_e')
    xlabel('Reduced frequency, kf [-]')
    ylabel('Response amplitude, |C(kf)| [-]')
    title('Theodorsen function','FontWeight','bold')
    xlim([0 max(kf)]);
    hold off
    
    hold off
    subplot(2,1,2);
    hold on
    grid on
    plot(kf_tmp(1:i),angle(Ckf_tmp(1:i))*S1,'-b','LineWidth',2) 
    plot(kf,angle(Ckf)*S1,'or','MarkerSize',8)
    %plot(kf_tmp(1:i),angle(frespCkf(1:i))*S1,'--g')
    legend('All frequencies','Vessel frequencies, w_e')
    xlabel('Reduced frequency, kf [-]')
    ylabel('Response phase, arg(C(kf)) [deg]')
    xlim([0 max(kf)]);
    hold off
    
    
    figure(figno+1)
    % Plotting actual Sears response and phase shift
    title('Sears function')
    subplot(2,1,1);
    hold on
    plot(kf_tmp(1:i),abs(Skf_tmp(1:i)),'k') 
    plot(kf,abs(Skf),'*k'); 
    title('Sears function','FontWeight','bold')
    legend('All frequencies','Vessel frequencies, w_e')
    xlabel('Reduced frequency, kf [-]')
    ylabel('Response amplitude, |S(kf)| [-]')
    hold off

    subplot(2,1,2);
    hold on
    plot(kf_tmp(1:i),angle(Skf_tmp(1:i))*S1,'k')
    plot(kf,angle(Skf)*S1,'*k'); 
    legend('All frequencies','Vessel frequencies, w_e')
    xlabel('Reduced frequency, kf [-]')
    ylabel('Response phase, arg(S(kf)) [deg]')
    hold off
    

    figure(figno+2)
    % Plotting results of fitting in logarithmic scale
    subplot(2,1,1);
    
    gain1 = 20*log10(abs(Ckf_tmp));
    gain2 = 20*log10(abs(frespCkf));
    semilogx(kf_tmp,gain1,'-b',kf_tmp,gain2,'r--','LineWidth',2);
    grid
    title('Theodorsen function (log-scale)','FontWeight','bold')
    xlabel('Reduced frequency, kf [-]')
    ylabel('Response amplitude, 20*log10(|C(kf)|) [dB]')
    
    
    subplot(2,1,2);
    
    phs1 = angle(Ckf_tmp)*S1;
    phs2 = angle(frespCkf)*S1;
    semilogx(kf_tmp,phs1,'-b',kf_tmp,phs2,'r--','LineWidth',2);
    xlabel('Reduced frequency, kf [-]')
    ylabel('Response phase, arg(C(kf)) [deg]')
    grid
    


%     figure(figno+2)
%     hold on
%     subplot(2,1,1);
%     gain1 = 20*log10(abs(Skf));
%     gain2 = 20*log10(abs(Skf_tmp));
%     gain3 = 20*log10(abs(frespSkf));
% 
%     semilogx(kf,gain1,'*k');
%     semilogx(kf_tmp,gain2,'k',kf_tmp,gain3,'k--');
% 
%     subplot(2,1,2);
% 
%     phs1 = angle(Skf)*S1;
%     phs2 = angle(Skf_tmp)*S1;
%     phs3 = angle(frespSkf)*S1;
% 
%     semilogx(kf,phs1,'*k');
%     semilogx(kf_tmp,phs2,'k',kf_tmp,phs3,'k--');
% 
%     hold off
end


end



