
function foil = foil2struct(foil,vessel)

% Retrieving variables from vessel and foil structure
rho = vessel.main.rho;
g   = vessel.main.g;

freqs   = vessel.freqs;
vels    = vessel.velocities;
heads   = vessel.headings;
nfreqs  = length(freqs);
nvels   = length(vels);
nheads  = length(heads);
ndof    = 6;

%foil = foilChar(foil);

xf   = foil.main.xf;
zf   = foil.main.zf;
span = foil.main.span;
cord = foil.main.cord;
CL   = foil.main.CL;

% Preallocating memory in matrices
[A B C]                   = deal(zeros(ndof,ndof,nfreqs,nheads,nvels));
[F,F_delta,F_unst,F_diff] = deal(zeros(ndof,1,nfreqs,nheads,nvels));
[Wave]                    = zeros(nfreqs,nheads,nvels);

% Defining added mass in 2D for a flat plate
a33  = rho*pi*(cord/2)^2;

% Declaring y as integratable, while assuming the foil to be a strip and
% hence keeping x=xf as constant and not integratable. Cord can thus 
% vary with respect to y (the input 'cord' then need to be altered)
syms y;

for i = 1:nvels;                                    % Loop over velocities
    
    U  = vels(i)+0.0001;                            % Velocity 
    dL = 0.5*rho*CL*U^2*cord;                       % Lift gradient
    
    for h = 1: nheads;                              % Loop over headings
        
        Beta = heads(h);                            % Heading
       
        for j = 1:nfreqs;                           % Loop over frequencies

            w   = freqs(j);                         % Frequency
            k   = w^2/g;                            % Wave number
            w_e = w + k*U*cos(Beta);                % Encounter frequency

            % Theodorsen and Sears' function - accounting for memory 
            % effects from foil dynamics in waves
            Theo  = theodorsen(cord,U,w_e);     
            
            % Wave particle transfer functions
            % -------------------------------------------------------------
            % W, vertical wave particle velocity divided by psi:
            % w_wave = psi*W, psi = -i*psi_a*e^(iwt). Here the phase due to
            % position is omitted from 'psi' and left at W to account for
            % the phase shift on foil compared to COG.
            W    = 1i*w*exp(k*zf)*exp(-1i*k*(xf*cos(Beta)+y*sin(Beta)));
            
            % Wdot, vertical wave particle acceleration divided by psi
            Wdot = 1i*w_e*W;
            
            % Diffraction forces
            % -------------------------------------------------------------
   
            % Added mass, A_di 
            rot  = [0 0 1 y -xf 0];                 % Rotational vector

            aij  = rot'*a33*rot;                    % Added mass matrix
            A_di = subs(int(aij,-span/2,span/2));   % Integration over span

            % Damping, B_di     
            bij  = [0 0 0 0 -U 0]'*a33*rot;         % Damping matrix
            B_di = subs(int(bij,-span/2,span/2));   % Integration over span
            
            % Excitation force transfer function, F_di = F/psi
            f_di = (Wdot*a33)*rot';                 % Force transfer func.
            F_di = subs(int(f_di,-span/2,span/2));  % Integration over span

            % Unsteady lift forces
            % -------------------------------------------------------------
            % (Minus 'one' due to contributions from pitch angle, resulting 
            % in system stiffness (Cij) - causes unsymmetrical matrices
            tij = rot'*dL*Theo*((1i*w_e/U)*rot + [0 0 0 0 -1 0]);       
            t   = subs(int(tij,-span/2,span/2));    % Integration over span 
            
            % Damiping and restoring, B_un and C_un
            B_un = 1/w_e*imag(t);                   % Damping matrix
            C_un = real(t);                         % Restoring matrix
            
            % Excitation force transfer function, F_un = F/psi
            f_un = (dL*Theo*W/U)*rot';              % Force transfer func.
            F_un = subs(int(f_un,-span/2,span/2));  % Integration over span
            
            % Excitation force transfer function from foil angle, d, Fd/psi
            fd_un = (dL*Theo)*rot';                  % Force transfer func.
            Fd_un = subs(int(fd_un,-span/2,span/2)); % Integration over span

            % Superposing the contributions
            % -----------------------------------------------------------------
            A(:,:,j,h,i) = A_di;
            B(:,:,j,h,i) = B_di + B_un;
            C(:,:,j,h,i) = C_un;
            
            F_diff(:,1,j,h,i) = F_di;
            F_unst(:,1,j,h,i) = F_un;
            
            F_wave            = F_di + F_un;
            F(:,1,j,h,i)      = F_wave;
            F_delta(:,1,j,h,i)= Fd_un;
            
            Wave(j,h,i)  = subs(W,0); % subs(W,0); % Subs with y = 0;
          
            for l = 1:ndof;
                foil.forceRAO.wave.complex{l}(j,h,i) = F_wave(l);
                foil.forceRAO.wave.amp{l}(j,h,i)     = abs(F_wave(l));
                foil.forceRAO.wave.phase{l}(j,h,i)   = angle(F_wave(l));
                
                foil.forceRAO.delta.complex{l}(j,h,i) = Fd_un(l);
                foil.forceRAO.delta.amp{l}(j,h,i)     = abs(Fd_un(l));
                foil.forceRAO.delta.phase{l}(j,h,i)   = angle(Fd_un(l));
            end

        end
        
    end
    
end

foil.freqs      = freqs;
foil.velocities = vels;
foil.headings   = heads;

foil.A    = A;
foil.B    = B;
foil.C    = C;
foil.F    = F;

foil.F_un = F_unst;
foil.F_di = F_diff;
foil.Fd   = F_delta;
foil.Wave = Wave;

% Creating motion RAO's for the foil-vessel system
foil = create_motionRAO(foil,vessel);





























